/* ==================================================================
   File:        config.cpp
   Author:      Steve Monks
   Description:
	Configuration module

 	$Id: config.cpp,v 1.3 2005/12/27 01:20:01 Steve Exp $
	$Log: config.cpp,v $
	Revision 1.3  2005/12/27 01:20:01  Steve
	Added Oversampling for <48KHz 16 bit audio
	Significant re-org and clean up of code
	
================================================================== */
#include <windows.h>
#include "stdio.h"
#include "config.h"

static char app_name[] = "Simple Kernel Streaming";


void Config::ReadString(char *name,char *data, int mlen)
{
	char buf[2048];
	strcpy(buf,data);
	GetPrivateProfileString(app_name,name,buf,data,mlen,file_name);
}


void Config::ReadInt(char *name,int *v)
{
	int def_v;

	def_v = *v;
	*v = GetPrivateProfileInt(app_name,name,def_v,file_name);
}



void Config::WriteString(char *name, char *data)
{
	WritePrivateProfileString(app_name,name,data,file_name);
}


void Config::WriteInt(char *name, int v)
{
	char txt[16];
	sprintf(txt,"%d",v);
	WritePrivateProfileString(app_name,name,txt,file_name);
}




Config::Config(void)
{
	char *dot;

	GetModuleFileName(NULL,file_name,sizeof(file_name));
	dot = strchr(file_name,'.');
	if (dot) {
		strcpy(dot,".ini");
	}

	Defaults();

	// get current settings from file (if any)
	Read();
}


void Config::Defaults(void)
{
	out_name[0] = 0;
	volume_enabled = FALSE;
	clean_up_after_track = TRUE;
	upsample = FALSE;
}

void Config::Read(void)
{

	ReadString("output_device",	out_name,sizeof(out_name));
	ReadInt("volume_enabled",		&volume_enabled);
	ReadInt("cleanup_on_close",	&clean_up_after_track);
	ReadInt("upsample",				&upsample);
}

void Config::Write(void)
{
	WriteString("output_device",	out_name);
	WriteInt("volume_enabled", 	volume_enabled);
	WriteInt("cleanup_on_close",	clean_up_after_track);
	WriteInt("upsample",				upsample);
}

