#include "kssample.h"
#include "stdarg.h"
#include "error.h"
#include "deviceinfo.h"

static DeviceInfoItem *device_info_list_head = NULL;
static DeviceInfoItem *device_info_list_tail = NULL;

DeviceInfoItem::DeviceInfoItem(char *name, char *path)
{
	if (device_info_list_tail)
		device_info_list_tail->succ = this;
	else
		device_info_list_head = this;

	prev = device_info_list_tail;
	succ = NULL;

	device_info_list_tail = this;


	friendly_name = (char *)malloc(strlen(name)+1);
	if (friendly_name)
		strcpy(friendly_name,name);

	device_path = (char *)malloc(strlen(path)+1);
	if (device_path)
		strcpy(device_path,path);
}


DeviceInfoItem::~DeviceInfoItem()
{
	if (friendly_name)
		free(friendly_name);
	if (device_path)
		free(device_path);

	if (prev)
		prev->succ = succ;
	else
		device_info_list_head = succ;

	if (succ)
		succ->prev = prev;
	else
		device_info_list_tail = prev;
}



void DestroyDeviceInfoList(void)
{
	while(device_info_list_head)
		delete(device_info_list_head);
}


//
// Builds a list of info items containing pairs of device names and paths
//
DeviceInfoItem *BuildDeviceInfoList(CKsEnumFilters *enumerator)
{
	CKsAudRenFilter* filter;
	DeviceInfoItem *info;

	device_info_list_head = device_info_list_tail = NULL;

	if (!enumerator)
		return NULL;

	LISTPOS lp = enumerator->m_listFilters.GetHeadPosition();
		
	do {
		filter = NULL;
		enumerator->m_listFilters.GetNext(lp, (CKsFilter**)&filter);						// get next entry from list
		if (!filter) break;																				// quit when no more

		info = new DeviceInfoItem(filter->GetFriendlyName(),filter->GetName());

	} while(1);

	return device_info_list_head;
}


